#[non_exhaustive]pub enum Error {
InvalidConnectToken,
EncryptFailed,
DecryptFailed,
InvalidPayloadSize(usize),
InvalidServerAddresses,
InvalidMaxClients(usize),
Io(Error),
}Expand description
Errors returned by this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidConnectToken
A connect token failed to parse or contained an invalid field.
EncryptFailed
AEAD encryption failed.
DecryptFailed
AEAD decryption failed. The data was tampered with or the wrong key was used.
InvalidPayloadSize(usize)
A payload size was outside the range [1, MAX_PAYLOAD_BYTES].
InvalidServerAddresses
The number of server addresses was outside the range [1, MAX_SERVERS_PER_CONNECT],
or the public and internal address lists had different lengths.
InvalidMaxClients(usize)
The requested number of client slots was outside the range [1, MAX_CLIENTS].
Io(Error)
A socket operation failed.